@@ -1,9 +1,10 @@
-import enum
 from pathlib import Path
 from typing import Final
 
+import nlib3
 
-class AiType(str, enum.Enum):
+
+class AiType(nlib3.StrEnum):
     categorical = "categorical"
     multi_label = "multi_label"
     regression = "regression"
@@ -11,27 +12,30 @@ class AiType(str, enum.Enum):
     gan = "genera_tive_adversarial_networks"
 
 
-class ModelType(str, enum.Enum):
-    unknown = "unknown"
+class ModelType(nlib3.StrEnum):
     vgg16_512 = "vgg16_512"
     mobile_net_v2 = "mobile_net_v2"
-    resnet_rs152_256 = "resnet_rs152_256"
-    resnet_rs152_512x2 = "resnet_rs152_512x2"
-    resnet_rs152_256_regr = "resnet_rs152_256_regr"
-    resnet_rs152_512x2_regr = "resnet_rs152_512x2_regr"
-    resnet_rs152_256_multi_label = "resnet_rs152_256_multi_label"
-    resnet_rs152_512x2_multi_label = "resnet_rs152_512x2_multi_label"
+    mobile_net_v2_regr = "mobile_net_v2_regr"
+    mobile_net_v2_multi_label = "mobile_net_v2_multi_label"
     efficient_net_v2_b0 = "efficient_net_v2_b0"
     efficient_net_v2_s = "efficient_net_v2_s"
     efficient_net_v2_b0_regr = "efficient_net_v2_b0_regr"
     efficient_net_v2_s_regr = "efficient_net_v2_s_regr"
     efficient_net_v2_b0_multi_label = "efficient_net_v2_b0_multi_label"
     efficient_net_v2_s_multi_label = "efficient_net_v2_s_multi_label"
+    resnet_rs152_256 = "resnet_rs152_256"
+    resnet_rs152_512x2 = "resnet_rs152_512x2"
+    resnet_rs152_256_regr = "resnet_rs152_256_regr"
+    resnet_rs152_512x2_regr = "resnet_rs152_512x2_regr"
+    resnet_rs152_256_multi_label = "resnet_rs152_256_multi_label"
+    resnet_rs152_512x2_multi_label = "resnet_rs152_512x2_multi_label"
 
     pix2pix = "pix2pix"
 
+    unknown = "unknown"
 
-class AiDataKey(str, enum.Enum):
+
+class AiDataKey(nlib3.StrEnum):
     version = "version"
     model = "model"
     ai_type = "ai_type"
@@ -46,7 +50,7 @@ class AiDataKey(str, enum.Enum):
     val_loss = "val_loss"
 
 
-class GanDataKey(str, enum.Enum):
+class GanDataKey(nlib3.StrEnum):
     gen_total_loss = "gen_total_loss"
     gen_gan_loss = "gen_gan_loss"
     gen_l1_loss = "gen_l1_loss"
